@@ -3,8 +3,9 @@ Main interface for cloudwatch service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.cloudwatch import (
+    from mypy_boto3_cloudwatch import (
         AlarmExistsWaiter,
         Client,
         CloudWatchClient,
@@ -16,7 +17,7 @@ Usage::
         ListDashboardsPaginator,
         ListMetricsPaginator,
         ServiceResource,
-        )
+    )
 
     session = boto3.Session()
 
@@ -34,8 +35,9 @@ Usage::
     get_metric_data_paginator: GetMetricDataPaginator = client.get_paginator("get_metric_data")
     list_dashboards_paginator: ListDashboardsPaginator = client.get_paginator("list_dashboards")
     list_metrics_paginator: ListMetricsPaginator = client.get_paginator("list_metrics")
+    ```
 """
-from mypy_boto3_cloudwatch.client import CloudWatchClient, CloudWatchClient as Client
+from mypy_boto3_cloudwatch.client import CloudWatchClient
 from mypy_boto3_cloudwatch.paginator import (
     DescribeAlarmHistoryPaginator,
     DescribeAlarmsPaginator,
@@ -43,12 +45,14 @@ from mypy_boto3_cloudwatch.paginator import (
     ListDashboardsPaginator,
     ListMetricsPaginator,
 )
-from mypy_boto3_cloudwatch.service_resource import (
-    CloudWatchServiceResource,
-    CloudWatchServiceResource as ServiceResource,
-)
+from mypy_boto3_cloudwatch.service_resource import CloudWatchServiceResource
 from mypy_boto3_cloudwatch.waiter import AlarmExistsWaiter, CompositeAlarmExistsWaiter
 
+Client = CloudWatchClient
+
+
+ServiceResource = CloudWatchServiceResource
+
 
 __all__ = (
     "AlarmExistsWaiter",
